Fitting FTIR data with multi lorentzian / Gaussian functions. 
The project is at it's early state for personal use-cases and data analysis.

## Intsallation

```console
pip install ftirfit==0.0.2

```
## Resources

1. [Rampy](https://github.com/charlesll/rampy)
2. [lmfit](https://lmfit.github.io/lmfit-py/fitting.html)
3. [PseudoVoigt](https://docs.mantidproject.org/nightly/fitting/fitfunctions/PseudoVoigt.html)
